@@ -10,20 +10,6 @@ class LeapDataType(Enum):
     Mask = 'Mask'
 
 
-class DatasetInputType(Enum):
-    Image = "Image"
-    Text = "Text"
-    Word = "Word"
-    Numeric = "Numeric"
-    Time_series = "Time_series"
-
-
-class DatasetOutputType(Enum):
-    Numeric = "Numeric"
-    Classes = "Classes"
-    Mask = "Mask"
-
-
 class DatasetMetadataType(Enum):
     float = "float"
     string = "string"
