@@ -2,8 +2,7 @@ from typing import List, Optional, Dict
 
 from dataclasses import dataclass, field
 
-from code_loader.contract.datasetclasses import DecoderReturnType
-from code_loader.contract.enums import DatasetInputType, DatasetMetadataType, DatasetOutputType
+from code_loader.contract.enums import DatasetMetadataType, LeapDataType
 
 
 @dataclass
@@ -38,7 +37,7 @@ class DatasetOutputInstance(DatasetBaseSectionInstance):
 @dataclass
 class DecoderInstance:
     name: str
-    type: DecoderReturnType
+    type: LeapDataType
 
 
 @dataclass
