@@ -4,10 +4,8 @@ import numpy as np  # type: ignore
 
 from code_loader.contract.datasetclasses import SectionCallableInterface, InputHandler, \
     GroundTruthHandler, MetadataHandler, DatasetIntegrationSetup, DecoderHandler, PreprocessResponse, \
-    PreprocessHandler, DecoderCallableInterface, DecoderReturnType
-from code_loader.contract.decoder_classes import LeapImage, LeapGraph, LeapNumeric, LeapHorizontalBar, LeapText, \
-    LeapMask
-from code_loader.contract.enums import DatasetInputType, DatasetOutputType, DatasetMetadataType
+    PreprocessHandler, DecoderCallableInterface
+from code_loader.contract.enums import DatasetMetadataType, LeapDataType
 from code_loader.decoders.default_decoders import DefaultDecoder, default_numeric_decoder, default_graph_decoder, \
     default_image_decoder, default_horizontal_bar_decoder, default_word_decoder, default_mask_decoder
 from code_loader.utils import to_numpy_return_wrapper
@@ -21,16 +19,16 @@ class DatasetBinder:
         self._extend_with_default_decoders()
 
     def _extend_with_default_decoders(self) -> None:
-        self.set_decoder(DefaultDecoder.Image.value, default_image_decoder, LeapImage)
-        self.set_decoder(DefaultDecoder.Graph.value, default_graph_decoder, LeapGraph)
-        self.set_decoder(DefaultDecoder.Numeric.value, default_numeric_decoder, LeapNumeric)
-        self.set_decoder(DefaultDecoder.HorizontalBar.value, default_horizontal_bar_decoder, LeapHorizontalBar)
-        self.set_decoder(DefaultDecoder.Text.value, default_word_decoder, LeapText)
-        self.set_decoder(DefaultDecoder.Mask.value, default_mask_decoder, LeapMask)
+        self.set_decoder(DefaultDecoder.Image.value, default_image_decoder, LeapDataType.Image)
+        self.set_decoder(DefaultDecoder.Graph.value, default_graph_decoder, LeapDataType.Graph)
+        self.set_decoder(DefaultDecoder.Numeric.value, default_numeric_decoder, LeapDataType.Numeric)
+        self.set_decoder(DefaultDecoder.HorizontalBar.value, default_horizontal_bar_decoder, LeapDataType.HorizontalBar)
+        self.set_decoder(DefaultDecoder.Text.value, default_word_decoder, LeapDataType.Text)
+        self.set_decoder(DefaultDecoder.Mask.value, default_mask_decoder, LeapDataType.Mask)
 
     def set_decoder(self, name: str,
                     decoder: DecoderCallableInterface,
-                    type: DecoderReturnType,
+                    type: LeapDataType,
                     heatmap_decoder: Optional[Callable[[np.array], np.array]] = None) -> None:
         self.setup_container.decoders.append(DecoderHandler(name, decoder, type, heatmap_decoder))
 
